@@ -7,13 +7,17 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 use Dist::Zilla;
 
 # Not used here, but we want it installed
 use Pod::Weaver::Section::Contributors;
 
+# Because Code::TidyAll does not depend on them
+use Perl::Critic;
+use Perl::Tidy;
+
 # For the benefit of AutoPrereqs
 use Dist::Zilla::Plugin::Authority;
 use Dist::Zilla::Plugin::AutoPrereqs;
@@ -444,7 +448,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =for Pod::Coverage .*
 
